.. Copyright (C) 2014-2020 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2014-2020 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _debops.mailman:

debops.mailman
==============

.. include:: man_description.rst
   :start-line: 7

.. toctree::
   :maxdepth: 2

   getting-started
   mailman2-migration
   defaults/main/environment
   defaults/main/core_configuration
   defaults/main/web_configuration
   defaults/main/hyperkitty_configuration
   defaults/main/ldap
   defaults/main/templates
   defaults/main/dependent
   defaults-detailed
   ldap-dit

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/mailman/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
